* -----------------------------------------------------------------------------
*
*   Reference: Four-loop splitting functions in QCD - The quark-to-gluon case - 
*
*              G. Falcioni, F. Herzog, S. Moch, A. Pelloni and A. Vogt
*              ZU-TH 20/24, DESY-24-053, LTH 1367
*
* -----------------------------------------------------------------------------
*
*   Quark-to-gluon anomalous dimensions gamma_gq(N) up to four loops,
*   fixed-N values at N =< 20
*
*   Notations: z3 = Zeta(3), ..., z5 = Zeta(5) are Riemann-zeta values,
*              nf = number of flavors; for the group invariants see the paper.
*              expansion in alpha_s/(4*pi): 
*              ggq0N2 (one-loop), ggq1N2 (two-loop), ggq2N2 (three-loop), 
*              ggq3N2 (four-loop) etc.
*              `-' relative to splitting functions
*
*   1) Four-loop moments at N =< 8 have been published before in:
*      Low moments of the four-loop splitting functions in QCD 
*      S. Moch, B. Ruijl, T. Ueda, J.A.M. Vermaseren, A. Vogt
*      arXiv:2111.15561 [hep-ph], Phys. Lett. B825 (2022), 136853
*
*   2) Four-loop moments at N =< 10 have been published before in:
*      Additional moments and x-space approximations
*         of four-loop splitting functions in QCD      
*      S. Moch, B. Ruijl, T. Ueda, J.A.M. Vermaseren, A. Vogt
*      arXiv:2310.05744[hep-ph], Phys.Lett.B 849 (2024) 138468
*
*   3) Four-loop moments at N =< 16 proportional to [d4RA/na] and [d4RR/na] 
*      have been published before in:
*      On quartic colour factors in splitting functions 
*         and the gluon cusp anomalous dimension
*      S. Moch, B. Ruijl, T. Ueda, J.A.M. Vermaseren, A. Vogt
*      arXiv:1805.09638 [hep-ph], Phys. Lett. B782 (2018), 627-632
*
* -----------------------------------------------------------------------------
******
* N=2
******  
L  ggq0N2=
      +cf*(-8/3);

L  ggq1N2=
      +cf*nf*(104/27)
      +cf*ca*(-376/27)
      +cf^2*(112/27);

L  ggq2N2=
      +cf*nf^2*(284/81)
      +cf*ca*nf*(22/9+128/3*z3)
      +cf*ca^2*(-20920/243-64/3*z3)
      +cf^2*nf*(7094/243-128/3*z3)
      +cf^2*ca*(8528/243+64*z3)
      +cf^3*(560/243-128/3*z3);

L  ggq3N2=
       + cf^4 * (  - 194392/2187 - 10880/81*z3 + 1280/3*z5 )
       + ca*cf^3 * (  - 238676/2187 - 31040/81*z3 + 704/3*z4 - 1280/3*z5 )
       + ca^2*cf^2 * ( 1626064/2187 + 25744/27*z3 - 352*z4 - 4480/9*z5 )
       + ca^3*cf * (  - 1734130/2187 - 34936/81*z3 + 352/3*z4 + 12160/27*z5 )
       + [d4RA/nc] * ( 736/9 - 1984/9*z3 - 5120/9*z5 )
       + nf*cf^3 * (  - 418850/2187 + 64/9*z3 - 640/9*z4 + 1280/3*z5 )
       + nf*ca*cf^2 * ( 695902/6561 - 6992/9*z3 + 3296/9*z4 - 640/9*z5 )
       + nf*ca^2*cf * ( 1841785/6561 + 63256/81*z3 - 2656/9*z4 - 8960/27*z5 )
       + nf*[d4RR/nc] * (  - 1856/9 - 1280/9*z3 + 5120/9*z5 )
       + nf^2*cf^2 * (  - 1060/6561 + 8704/81*z3 - 512/9*z4 )
       + nf^2*ca*cf * (  - 217798/6561 - 272/3*z3 + 512/9*z4 )
       + nf^3*cf * ( 6160/2187 - 512/81*z3 );

******
* N=4
******  
L  ggq0N4=
      +cf*(-11/15);

L  ggq1N4=
      +cf*nf*(313/675)
      +cf*ca*(-63949/13500)
      +cf^2*(42109/27000);

L  ggq2N4=
      +cf*nf^2*(54731/40500)
      +cf*ca*nf*(-799/48600+176/15*z3)
      +cf*ca^2*(-325575847/12150000-944/75*z3)
      +cf^2*nf*(3651671/759375-176/15*z3)
      +cf^2*ca*(-117100723/24300000+944/25*z3)
      +cf^3*(110687611/6075000-1888/75*z3);

L  ggq3N4 =
       + cf^4 * (  - 1438431824489/17496000000 - 21061493/101250*z3 + 259/5*z4
          + 14408/45*z5 )
       + ca*cf^3 * ( 270563159561/8748000000 + 6105179/101250*z3 + 5917/750*z4
          - 17488/45*z5 )
       + ca^2*cf^2 * ( 1259255579057/4374000000 + 16267093/67500*z3 - 25621/
         250*z4 + 1484/45*z5 )
       + ca^3*cf * (  - 632341192829/2187000000 - 1120409/8100*z3 + 16048/375*
         z4 + 8782/135*z5 )
       + [d4RA/nc] * (  - 12196/135 - 81008/225*z3 + 15976/45*z5 )
       + nf*cf^3 * (  - 316818132031/3280500000 + 411629/16875*z3 - 4582/225*
         z4 + 352/3*z5 )
       + nf*ca*cf^2 * ( 569679966383/6561000000 - 13919446/50625*z3 + 12501/
         125*z4 - 176/9*z5 )
       + nf*ca^2*cf * ( 2203719743/52488000 + 2857549/11250*z3 - 89599/1125*z4
          - 11872/135*z5 )
       + nf*[d4RR/nc] * (  - 112424/675 - 2336/75*z3 + 10624/45*z5 )
       + nf^2*cf^2 * ( 9798304643/3280500000 + 17096/675*z3 - 704/45*z4 )
       + nf^2*ca*cf * (  - 1608863899/328050000 - 39416/2025*z3 + 704/45*z4 )
       + nf^3*cf * ( 3990397/2733750 - 704/405*z3 );

******
* N=6
******
L  ggq0N6=
      +cf*(-44/105);

L  ggq1N6=
      +cf*nf*(2204/33075)
      +cf*ca*(-437033/154350)
      +cf^2*(1191271/1157625);

L  ggq2N6=
      +cf*nf^2*(2833459/3472875)
      +cf*ca*nf*(-253841107/583443000+704/105*z3)
      +cf*ca^2*(-202913519537/16336404000-37592/3675*z3)
      +cf^2*nf*(20157323311/10210252500-704/105*z3)
      +cf^2*ca*(-150561431231/10210252500+37592/1225*z3)
      +cf^3*(1031558954593/51051262500-75184/3675*z3);

L  ggq3N6 =
       + cf^4 * ( - 27548846012571077/225136067625000 
         - 28516720088/121550625*z3 + 6416/105*z4 + 260192/735*z5 )
       + ca*cf^3 * ( 15370144370986843/90054427050000 
         + 23472335174/121550625*z3 - 1023364/25725*z4 - 370016/735*z5 )
       + ca^2*cf^2 * ( 58564721355491371/720435416400000 
         + 10781187328/121550625*z3 - 1215814/25725*z4 + 373832/2205*z5 )
       + ca^3*cf * ( - 133292466369681947/864522499680000 
         - 226736591/2701125*z3 + 667258/25725*z4 + 67288/6615*z5 )
       + [d4RA/nc] * ( - 23820479/330750 - 46510952/165375*z3 + 114496/315*z5 )
       + nf*cf^3 * ( - 75665018489451691/1350816405750000 
          + 187225352/24310125*z3 - 36352/2205*z4 + 1408/21*z5 )
       + nf*ca*cf^2 * ( 331099053590779/6003628470000 - 3771301108/24310125*z3
          + 4877248/77175*z4 - 704/63*z5 )
       + nf*ca^2*cf * ( 40511222207957/3430644840000 + 3610221368/24310125*z3
          - 3604928/77175*z4 - 65344/1323*z5 )
       + nf*[d4RR/nc] * ( - 2663932/23625 - 770944/33075*z3 + 68608/441*z5 )
       + nf^2*cf^2 * ( 27562736653631/9648688612500 + 266912/19845*z3 
          - 2816/315*z4 )
       + nf^2*ca*cf * ( - 301286343367/110270727000 - 944432/99225*z3
          + 2816/315*z4 )
       + nf^3*cf * ( 3574461862/3281866875 - 2816/2835*z3 );

******
* N=8
******
L  ggq0N8=
      +cf*(-37/126);

L  ggq1N8=
      +cf*nf*(-12613/238140)
      +cf*ca*(-58805263/28576800)
      +cf^2*(331619149/400075200);

L  ggq2N8=
      +cf*nf^2*(339184373/600112800)
      +cf*ca*nf*(-3105820553/6751269000+296/63*z3)
      +cf*ca^2*(-840976971727/129624364800-58649/6615*z3)
      +cf^2*nf*(8498139408671/9073705536000-296/63*z3)
      +cf^2*ca*(-16504689458671/907370553600+58649/2205*z3)
      +cf^3*(12876352060509647/635159387520000-117298/6615*z3);

L  ggq3N8 = 
       + cf^4 * ( - 24543597526270550844943/161340646980280320000 
          - 15301069838573/63011844000*z3 + 10747/168*z4 + 213596/567*z5 )
       + ca*cf^3 * ( 6310523848625645534759/24009024848256000000 
          + 15872437061239/63011844000*z3 - 291860591/4762800*z4 
          - 2286556/3969*z5 )
       + ca^2*cf^2 * ( - 87368680167927504727/2572395519456000000 
          + 291378678971/14002632000*z3 - 31798217/1587600*z4 + 4982/21*z5 )
       + ca^3*cf * ( - 133262292247883142773/1469940296832000000 
          - 1106936590687/18003384000*z3 + 5161112/297675*z4 - 73193/7938*z5 )
       + [d4RA/nc] * ( - 273996244909/4320812160 - 137047639/555660*z3 
          + 151490/441*z5 )
       + nf*cf^3 * ( - 50125745829108214529/1371944277043200000 
          - 292991233/150028200*z3 - 580927/39690*z4 + 2960/63*z5 )
       + nf*ca*cf^2 * ( 77269186724872290241/2057916415564800000 
          - 6495831967/64297800*z3 + 22993211/476280*z4 - 1480/189*z5 )
       + nf*ca^2*cf * ( 89928989976567629/32665339929600000 
          + 8867614661/85730400*z3 - 16022087/476280*z4 - 58420/1701*z5 )
       + nf*[d4RR/nc] * ( - 2023939021/24111675 - 3285578/178605*z3 
          + 65440/567*z5 )
       + nf^2*cf^2 * ( 269507034349861709/102895820778240000 + 10846/1215*z3
          - 1184/189*z4 )
       + nf^2*ca*cf * ( - 383192836407971/174992892480000 - 349492/59535*z3
          + 1184/189*z4 )
       + nf^3*cf * ( 1517401222367/1701319788000 - 1184/1701*z3 );

******
* N=10
******
L  ggq0N10=
      +cf*(-112/495);

L  ggq1N10=
      +cf*nf*(-74368/735075)
      +cf*ca*(-133349533/80858250)
      +cf^2*(88631998/121287375);

L  ggq2N10=
      +cf*nf^2*(152267426/363862125)
      +cf*ca*nf*(-18846629176433/47069204490000+1792/495*z3)
      +cf*ca^2*(-165894431274725803/48324383276400000-645584/81675*z3)
      +cf^2*nf*(529979902254031/1294403123475000-1792/495*z3)
      +cf^2*ca*(-4224421791031474951/217459724743800000+645584/27225*z3)
      +cf^3*(6457897459084371893/326189587115700000-1291168/81675*z3);

L  ggq3N10 =
       + cf^4 * ( - 10853673038701241183091951323/62660889209091123720000000
          - 726934765981684/2941825280625*z3 + 16751072/259875*z4
          + 19310144/49005*z5 )
       + ca*cf^3 * ( 542937177948206382842582969/1670957045575763299200000
          + 31493864059633/108956491875*z3 - 6864965416/94334625*z4
          - 6174656/9801*z5 )
       + ca^2*cf^2 * ( - 176439961207867804097579923/
          1670957045575763299200000 - 579719752264/28017383625*z3
          - 4242844/1164625*z4 + 4582256/16335*z5 )
       + ca^3*cf *  ( - 1523068185119005263091080961/27849284092929388320000000
          - 5408146393855729/109828143810000*z3 + 1127996644/94334625*z4
          - 523568/29403*z5 )
       + [d4RA/nc] * ( - 1269333487356283/21784094640000
          - 769373679649/3438146250* z3 + 15732224/49005*z5 )
       + nf*cf^3 * ( - 56013386247927639171031907/2237888900324682990000000
          - 365131853104/46695639375*z3 - 652192/49005*z4 + 3584/99*z5 )
       + nf*ca*cf^2 * ( 39336775666814707823343377/1491925933549788660000000
          - 1973089362212/28017383625*z3 + 179052352/4492125*z4 - 1792/297*z5 )
       + nf*ca^2*cf * ( - 35738891348053198625123/45209876774236020000000
          + 76945028642074/980608426875*z3 - 357804256/13476375*z4
          - 1291648/49005*z5 )
       + nf*[d4RR/nc] * ( - 181205970624529/2723011830000
          - 4515702496/300155625*z3 + 1494016/16335*z5 )
       + nf^2*cf^2 * ( 7082606576237379049/2990071215227250000
          + 4834432/735075*z3 - 7168/1485*z4 )
       + nf^2*ca*cf * ( - 74338063361300467/38126055636900000
          - 8906512/2205225*z3 + 7168/1485*z4 )
       + nf^3*cf * ( 1730630298974/2269408073625 - 7168/13365*z3 );  

******
* N=12
******
L  ggq0N12=
      +cf*(-79/429);

L  ggq1N12=
      +cf*nf*(-14257247/115945830)
      +cf*ca*(-70863259553/50645138544)
      +cf^2*(9387059226553/13927413099600);

L  ggq2N12=
      +cf*nf^2*(13454024393417/41782239298800)
      +cf*ca*nf*(-64190493078139789/195540879918384000+1264/429*z3)
      +cf*ca^2*(-24751969909767240119153/14947144860961272960000-46179137/6441435*z3)
      +cf^2*nf*(1401404001326440151/13981172914164456000-1264/429*z3)
      +cf^2*ca*(-115986599183122809974023/5872092623949071520000+46179137/2147145*z3)
      +cf^3*(2165927305724992215894703/113037783011019626760000-92358274/6441435*z3);

L  ggq3N12=
      +[d4RA/nc]*(-113527295175322043699/2082683928124800000+1159790344/3864861*z5-66259676094769/321401840760*z3)
      +nf*[d4RR/nc]*(-14322664324006372519/260335491015600000+421760/5577*z5-33040603052/2608781175*z3)
      +cf*nf^3*(2265689177355445577/3387745744586002800-5056/11583*z3)
      +cf*ca*nf^2*(-1990546832712974636980331/1109825505926374517280000+5056/1287*z4-171649172/57972915*z3)
      +cf*ca^2*nf*(-3409052330654655340645389731/1469005396935273906508800000-119360/5577*z5
         -5541945667/251215965*z4+25514383657902523/407376833163300*z3)
      +cf*ca^3*(-605797324486893500585306535221627/18906099458556975176768256000000-23156863/1054053*z5+79289578229/9591882300*z4-1052537460264167687/
	     25347891841272000*z3)
      +cf^2*nf^2*(169033294355320918596314039/79352523673735777985520000-5056/1287*z4+81408784/15810795*z3)
      +cf^2*ca*nf*(2936117949737136383600864384611/157550828821308126473068800000-6320/1287*z5
         +8619754063/251215965*z4-3457752318647119/67896138860550*z3)
      +cf^2*ca^2*(-224250321575347263949905289161744199/1455769658308887088611155712000000+1211419205/3864861*z5
         +3810092749/532882350*z4-2010183037743051616/39210020191967625*z3)
      +cf^3*nf*(-332043482084304364183967274124153/19063650287378283303241324800000+12640/429*z5
         -6070628/495495*z4-393343213522261/33948069430275*z3)
      +cf^3*ca*(422699180143530974480654228020604813/1143819017242696998194479488000000-237624788/351351*z5
         -760772056049/9591882300*z4+100064481514290063961/313680161535741000*z3)
      +cf^4*(-25682557611275387813242057003995677/135916765937789612439776112000000+17406716/42471*z5
         +12335483/193050*z4-78873286642153277627/313680161535741000*z3);

******
* N=14
******
L ggq0N14 =
       + cf * (  - 212/1365 );

L ggq1N14 =
       + cf*nf * (  - 24528122/184459275 )
       + cf*ca * (  - 2098207279237/1704403701000 )
       + cf^2 * ( 7056537497441/11078624056500 );

L ggq2N14 =
       + cf*nf^2 * ( 9642501137/37983853908 )
       + cf*ca*nf * (  - 37115284124613269/141738211775160000 + 3392/1365*z3 )
       + cf*ca^2 * (  - 367463622580694294537/681023759937288768000 - 134890564/20495475*z3 )
       + cf^2*nf * (  - 40163401444446690479/419190761325035700000 - 3392/1365*z3 )
       + cf^2*ca * (  - 1087893142073882090700071/55333180494904712400000 + 134890564/6831825*z3 )
       + cf^3 * ( 950103014669407668516827/51380810459554375800000 - 269781128/20495475*z3 );

L  ggq3N14=
      +[d4RA/nc]*(-21335213154567939744419/414584269442343000000+3460252064/12297285*z5-613323018929398364/3198952696314375*z3)
      +nf*[d4RR/nc]*(-86703311715954607957/1850822631439031250+615424/9555*z5-244011856707712/22370298575625*z3)
      +cf*nf^3*(321519364624645823/538959550275045900-13568/36855*z3)
      +cf*ca*nf^2*(-2493111180935243429476603/1493995873362427234800000+13568/4095*z4-83451856/36891855*z3)
      +cf*ca^2*nf*(-958430136662854610670607569547/322105510296939311822880000000-4416/245*z5
         -40764233512/2152024875*z4+9023658476762282/174488328889875*z3)
      +cf*ca^3*(-4272807969344509309643357544788243/255107564155175934963720960000000-177252716/7378371*z5+794134472909/142033641750*z4-
         926544367976770183/25591621570515000*z3)
      +cf^2*nf^2*(649724993957136005232607141/339884061189952195917000000-13568/4095*z4+178574416/42567525*z3)
      +cf^2*ca*nf*(40759120798908335841181047497491/3140528725395158290273080000000-3392/819*z5
         +65246478712/2152024875*z4-992731197367267/26437625589375*z3)
      +cf^2*ca^2*(-62684886023029557261923348044015457/331639833401728715452837248000000+4199718508/12297285*z5
         +231212408549/15781515750*z4-173609406082076933/2268348275568375*z3)
      +cf^3*nf*(-490379446041031040879323234108051/40826873430137057773550040000000+6784/273*z5-46632848/4099095*z4
         -33894392681638/2403420508125*z3)
      +cf^3*ca*(435029240281577148104394100536180709/1077829458555618325221721056000000-160919504/223587*z5
         -5900838170593/71016820875*z4+172973892630128742931/499036620625042500*z3)
      +cf^4*(-1175858514183978179181088212329622671/5838242900509599261617655720000000+5234629744/12297285*z5
         +10403997892/165540375*z4-32053546295279752556/124759155156260625*z3);

******
* N=16
******
L ggq0N16 =
       + cf * (  - 137/1020 );

L ggq1N16 =
       + cf*nf * (  - 1285080631/9372963600 )
       + cf*ca * (  - 8498940355924253/7655986635897600 )
       + cf^2 * ( 1335241147577159/2187424753113600 );

L ggq2N16 =
       + cf*nf^2 * ( 667095577675187/3281137129670400 )
       + cf*ca*nf * (  - 72128498884648832272063/351761196374287539840000 + 548/255*z3 )
       + cf*ca^2 * ( 318248952934239021250947659/1596245407653666950788608000 - 1587621953/260360100*z3 )
       + cf^2*nf * (  - 21629477476233033651859129/95679045413806210836480000 - 548/255*z3 )
       + cf^2*ca * (  - 2318741239910436139532909474219/119718405574025021309145600000 + 1587621953/86786700*z3 )
       + cf^3 * ( 51250781225285493025982801352523/2873241733776600511419494400000 - 1587621953/130180050*z3 );

L  ggq3N16=
      +[d4RA/nc]*(-11773700142311179915702121/240974431125652224000000+4137449651/15621606*z5-101169081992668980737/563503134009816000*z3)
      +nf*[d4RR/nc]*(-405223386945234740808587/9940195283933154240000+145816/2601*z5-14956670451523/1563722760600*z3)
      +cf*nf^3*(34108337373135323374301/63317015347371757171200-2192/6885*z3)
      +cf*ca*nf^2*(-60504685061989103630936679672439/38788763405984106904163174400000+2192/765*z4-3125731858/1757430675*z3)
      +cf*ca^2*nf*(-2033308368213027173938918062479854873193/633665651404446285300618949214208000000-121513/7803*z5
         -3535338880967/212453841600*z4+15529936726131895757/354959380391616000*z3)
      +cf*ca^3*(-317835545673384782764570229718975673012928297/53915441949747312184803163293890887680000000-23407688153/937296360*z5+475554692179667/
         132916434651000*z4-1262927249130586239359921/39084577374920837760000*z3)
      +cf^2*nf^2*(9044520444067665064750987439226131/5275271823213838538966191718400000-2192/765*z4+4119326989/1171620450*z3)
      +cf^2*ca*nf*(93344344164963857590569964407611700892711/10772316073875586850110522136641536000000-548/153*z5
         +643872057559/23605982400*z4-2475119092628220127/88739845097904000*z3)
      +cf^2*ca^2*(-2905887663991964454299544802600912038519944459/13478860487436828046200790823472721920000000
         +93724168/255255*z5+14216141064343763/708887651472000*z4-14062285015933017481879/142125735908803046400*z3)
      +cf^3*nf*(-57298339123449136718474401962230424513361/7181544049250391233407014757761024000000+1096/51*z5
         -16614041449/1562160600*z4-87782813700795439/5546240318619000*z3)
      +cf^3*ca*(69709103720766489723595997659712410526245706881/161746325849241936554409489881672663040000000
         -2706171203/3550365*z5-181207395103216571/2126662954416000*z4+561806270069913957735019/1503252975958493760000*z3)
      +cf^4*(-91333794681488605852642048633486608590877607351/431323535597978497478425306351127101440000000
         +2466482078/5579145*z5+105621100681/1715313600*z4-15461805996412648565848919/58626866062381256640000*z3);

******
* N=18
******
L ggq0N18 =
       + cf * (  - 344/2907 );

L ggq1N18 =
       + cf*nf * (  - 1946980678/14098499415 )
       + cf*ca * (  - 59001125762000533/57918101840759160 )
       + cf^2 * ( 82988034461232619/140658247327557960 );

L ggq2N18 =
       + cf*nf^2 * ( 9914293314660571/60282105997524840 )
       + cf*ca*nf * (  - 31887675747646821779321527/202243547967765557997744000 + 5504/2907*z3 )
       + cf*ca^2 * ( 1359249168614788628629647966521/1923235019399466573779546568000 - 80233274684/14098499415*z3 )
       + cf^2*nf * (  - 30880135001014980658896468461/97986998990382412849906968000 - 5504/2907*z3 )
       + cf^2*ca * (  - 148923427056152134789661050356089507/7846798879149823621020549997440000 + 80233274684/4699499805*z3 )
       + cf^3 * ( 574155496668780010688383657023881173/33348895236386750389337337489120000 - 160466549368/14098499415*z3 );

L  ggq3N18=
      +[d4RA/nc]*(-1534254855736463458285860487597/32941608367048794488275200000+705610821248/2819699883*z5-263063336077755987407089/1556198430038208356400*z3)
      +nf*[d4RR/nc]*(-2376495270782792811304983137/65883216734097588976550400+24663040/497097*z5-9726278907372152/1143120431067615*z3)
      +cf*nf^3*(25322735830563737715837587/51572104731780217289424720-22016/78489*z3)
      +cf*ca*nf^2*(-51603554118665492025456278063355347/35310594956174206294592474988480000+22016/8721*z4-543557988224/380659484205*z3)
      +cf*ca^2*nf*(-936013096859225678199723846435281783145737/290119192763678163151281049740149283840000
         -20446720/1491291*z5-35839946880856/2410843399965*z4+122057786649260319779/3237844654828593810*z3)
      +cf*ca^3*(115832786415748476638280610626833293796768491507/55177769271723949849742142850078992293529600000-214104770108/8459099649*z5+
         9748563515611381/4826508486729930*z4-395558870241334146068201903/13482903197851037199849600*z3)
      +cf^2*nf^2*(2076988113916115506387549621182589219/1350630257073663390768162168309360000-22016/8721*z4+13478091680/4478346873*z3)
      +cf^2*ca*nf*(494213149462187941188004051358795571999087887/93708499262668046697863779066068218680320000
         -27520/8721*z5+59943194135296/2410843399965*z4-197585480953102482619/9566359207448118075*z3)
      +cf^2*ca^2*(-123319626596597732563913557669030322668202344255007/521123376455170637469786904695190482772224000000
         +1104257588788/2819699883*z5+7737412238766461/321767232448662*z4-97421341297611056710882606/813953673165723126411375*z3)
      +cf^3*nf*(-154871348508574160288273783965897373976839491/31860889749307135877273684882463194351308800
         +55040/2907*z5-84572797384/8459099649*z4-18100451697075180817/1062928800827568675*z3)
      +cf^3*ca*(1703079039178221518412667538347685102671198180332127/3752088310477228589782465713805371475960012800000
         -618848170736/769009059*z5-208211747676885206/2413254243364965*z4+58151956931435413049516329/144995796029521528591500*z3)
      +cf^4*(-199441346676346613221100951050417553229794351172058063/903627934773265885372610492741460297127036416000000
         +555009226736/1208442807*z5+55191569546/916620705*z4-9734182701413671124997104021/35813961619291817562100500*z3);

******
* N=20
******
L ggq0N20 =
       + cf * (  - 211/1995 );

L ggq1N20 =
       + cf*nf * (  - 3189320461/23221057860 )
       + cf*ca * (  - 192438850157107667/203221409967576000 )
       + cf^2 * ( 15497966507213747233/27028447525687608000 );

L ggq2N20 =
       + cf*nf^2 * ( 2169659074824975427/16217068515412564800 )
       + cf*ca*nf * (  - 6195326325494922813709097/52288267249283800775040000 + 3376/1995*z3 )
       + cf*ca^2 * ( 179930905499554129650243042051217/169059994318401863179882579200000 - 11487554623/2150097950*z3 )
       + cf^2*nf * (  - 124571179293472837713239549569/330331128347350411396315200000 - 3376/1995*z3 )
       + cf^2*ca * (  - 3094660566684977134578674594904043/166864409976604436385338649600000 + 34462663869/2150097950*z3 )
       + cf^3 * ( 761433800155529524086425815443537119/45772993461707304455953208318400000 - 11487554623/1075048975*z3 );

L  ggq3N20=
      +[d4RA/nc]*(-9934247787263135793881744121471193/223044635561617655771521536000000+153050440696/645029385*z5-20055818840172257506705213/125439024966716188728000*z3)
      +nf*[d4RR/nc]*(-2704920902087866223629472523102433/83641738335606620914320576000000+1863808/41895*z5-108318373596246439/14144672000584125*z3)
      +cf*nf^3*(23642031766087097685137941/52433512436087366888304000-13504/53865*z3)
      +cf*ca*nf^2*(-11325534673549584438954822499666967/8259788293841919601074263155200000+13504/5985*z4-11266215274/9675440775*z3)
      +cf*ca^2*nf*(-465634445017831591325444801806925052804292331/148765335532252329889207211100981442560000000
         -1539424/125685*z5-4555835727754/338640427125*z4+3171458341939781449/96255155006010000*z3)
      +cf*ca^3*(8128052126051322869747930125993834197558195023/996276944019023178954993747070209054720000000-10876666809/430019590*z5+494114186999099/
         627226573974000*z4-4468686144075569343986511569/165579512956065369120960000*z3)
      +cf^2*nf^2*(4773708126683882394527205560488250927/3460438305705072216870062548871040000-13504/5985*z4+4000788628/1527701175*z3)
      +cf^2*ca*nf*(102664753783997698300409838737001288852130553/40379162501611346684213385870266391552000000
         -3376/1197*z5+2584501408063/112880142375*z4-5347393544742883698797/354748373774649855000*z3)
      +cf^2*ca^2*(-13595171979898487398112366060650503619924613365949/53542769477136645703266949663973235197952000000
         +178657350101/430019590*z5+1068938712970319969/39515274160362000*z4-13706603212061214884924310847/98312835817663812915570000*z3)
      +cf^3*nf*(-941248780576101712647404838543624320767081907/394884456817228610955910317701869858560000000
         +6752/399*z5-91361957041/9675440775*z4-6339794916091394356451/354748373774649855000*z3)
      +cf^3*ca*(742257701799954265313171119485669995895179080771700597/1566661434901018253277590947167856861892075520000000
         -149116082954/175917105*z5-570786749229593761/6585879026727000*z4+304638383107094264933207/710296405760118870000*z3)
      +cf^4*(-18011842890292937504270512411100571563413211395232599/78747532442114674106545576709495450730024960000000
         +923526447854/1935088155*z5+57192203098/972173475*z4-27623613597125033101695488051/98312835817663812915570000*z3);

* -----------------------------------------------------------------------------

*
*   Quark-to-gluon anomalous dimensions gamma_gq(N) up to four loops,
*   all-N results for particular terms
*
*   Notations:
*   S(R(m1,...,mk),N) denotes harmonic sums,
*   z3 = Zeta(3), ... , z5 = Zeta(5),
*   den(x) = 1/x denotes denominators
*   nf = number of flavors; for the group invariants see the paper.
*   expansion in alpha_s/(4*pi)
*

****** 
*  gamma_gq^{(3)}(N) at even N: contributions proportional to Zeta(3) for
*     nf*[d4RA/na], nf^2*[d4RR/na], cf^3*nf, cf*{cf,ca}*nf^2, cf*nf^3 
*
*  Note: the cf^3*nf and cf*ca*nf^2 parts includes a term ~delta(N-2), 
*        cf the DIS coefficient functions at two and three loops.
*
*  For the quartics this file uses
*  
*    eta =         1/N   - 1/(N+1)    = 1/{N*(N+1)} 
*    nu  =      1/(N-1)  - 1/(N+2)    = 3/{(N-1)*(N+2)} 
*   
*  CARE: the latter is not the only definition than has been used.
******

 L ggq3z3N =

  + [d4RA/nc]* 128*z3* (
       ( 7/12
       + 33/2* eta
       - 96* S(R(1),N)* eta
       + 32* S(R(1),N)* nu
       - 24* S(R(-2),N)
       - 6* S(R(1),N)* eta^2
       + 10* S(R(-2),N)* eta
       - 16* S(R(-2),N)* nu
       + 43* S(R(1),N)^2* eta
       - 16* S(R(1),N)^2* nu
       - 8* (S(R(-2,1),N)-S(R(1,-2),N))
       + 8* S(R(1),N)*S(R(-2),N)
       - 1* S(R(3),N)
     ) * (2*den(N-1)-2*den(N)+den(N+1))
     + ( - 40
       - 24* S(R(1),N)
       + 72* S(R(-2),N)
       + 10* S(R(1),N)^2
       - 72* (S(R(-2,1),N)-S(R(1,-2),N))
       - 72* S(R(1),N)*S(R(-2),N)
       - 36* S(R(3),N)
     ) * den(N-1)*den(N+1)*den(N)
    )

  + [d4RR/nc]*nf* 256*z3* (
     ( - 7/12
       - 3* eta
       - 8* S(R(1),N)* eta^2
       + 8* S(R(-2),N)* eta
     ) * (2*den(N-1)-2*den(N)+den(N+1))
     + ( 4
       - 16* S(R(-2),N)
     ) * den(N-1)*den(N)*den(N+1)
    )
 
  + cf^3*nf* 32/9* z3* (
       - 1372/3*den(-1+N)
       - 2233/2*den(N)
       + 6049/4*den(1+N)
       - 20/3*den(2+N)
       - 16*den(-1+N)^2
       + 1477*den(N)^2
       + 305*den(1+N)^2
       + 32*den(2+N)^2
       - 186 *den(N)^3
       - 87*den(1+N)^3
       + 216* (den(N)^4 - den(1+N)^4)
     + S(R(1),N) * (
       - 30*den(-1+N)
       + 856 *den(N)
       - 725*den(1+N)
       + 32*den(2+N)
       + 96*den(-1+N)^2
       - 288*den(N)^2
       - 300*den(1+N)^2
       + 108* (2*den(N)^3 - den(1+N)^3)
       )
    - 78* S(R(1,1),N) * (2*den(-1+N) - 2*den(N) + den(1+N))
    + 72* S(R(2),N) * (2*den(-1+N) - 2*den(N) + den(1+N))
    + 60* S(R(-2),N) * (2*den(-1+N) - 2*den(N) + den(1+N))
    - 10/3* delta_(N-2)
    )
 
  + cf^2*nf^2* 64/27* z3* (
       + 52*den(-1+N)
       - 89*den(N)
       + 76*den(1+N)
       + 4*den(2+N)
       + 12*den(-1+N)^2
       + 42*den(N)^2
       + 9*den(1+N)^2
    - 6* S(R(1),N) * (2*den(-1+N) - 2*den(N) + den(1+N))
    )

  + cf*ca*nf^2* 32/9* z3* (
       - 103/3*den(-1+N)
       + 63*den(N)
       - 54*den(1+N)
       - 8/3*den(2+N)
       - 8*den(-1+N)^2
       - 28*den(N)^2
       - 12*den(1+N)^2
    + 6* S(R(1),N) * (2*den(-1+N) - 2*den(N) + den(1+N))
    + 1/3* delta_(N-2)
    )
    - cf*nf^3* z3*128/27 * (2*den(-1+N) - 2*den(N) + den(1+N))
    ;

****** 
*  gamma_gq^{(3)}(N) at even N: contributions proportional to Zeta(5)
*
*  cf^2*{cf^2,cf*ca,ca^2} include terms ~(N+2), to be cancelled for
*  N->oo by non-z5 contributions. The pattern of these terms is the
*  same as for those ~(N-1) in the cf*nf*{cf^2,cf*ca,ca^2} parts of
*  gamma_qg. They vanish for cf = ca, i.e., in the N=1 SUSY limit.
******

 L ggq3z5N =

  + cf^4* 160*z5* (
       1/12* (N+2)
     - 239/3* den(N)
     + 473/6* den(N+1)
     - 28* den(N-1)
     + 52* den(N)^2
     + 26* den(N+1)^2
     + 14* (2*den(N-1)-2*den(N)+den(N+1))* S(R(1),N)
     )
  + cf^3*ca* 160*z5* (
     - 1/6* (N+2)
     + 442/3* den(N)
     + 44* den(N-1)
     - 428/3* den(N+1)
     - 92* den(N)^2
     - 46* den(N+1)^2
     - 22* (2*den(N-1)-2*den(N)+den(N+1))* S(R(1),N)
     )
  + cf^2*ca^2* 80*z5* (
       1/6* (N+2)
     - 548/3* den(N)
     + 1007/6* den(N+1)
     - 44* den(N-1)
     - 8/3* den(N+2)
     + 102* den(N)^2
     + 51* den(N+1)^2
     - 8* den(N-1)^2
     + 25* (2*den(N-1)-2*den(N)+den(N+1))* S(R(1),N)
     )
  + cf*ca^3* 80/3*z5* (
       224/3* den(N)
     - 166/3* den(N+1)
     + 26* den(N-1)
     + 16/3* den(N+2)
     - 24* den(N)^2
     - 12* den(N+1)^2
     + 16* den(N-1)^2
     - 19* (2*den(N-1)-2*den(N)+den(N+1))* S(R(1),N)
     )
  + [d4RA/nc]* 320*z5* (
     - 202/3 * den(N)
     + 391/6 * den(N+1)
     - 10 * den(N-1)
     - 8/3 * den(N+2)
     + 42 * den(N)^2
     + 21 * den(N+1)^2
     - 8 * den(N-1)^2
     + 8 * (2*den(N-1)-2*den(N)+den(N+1))* S(R(1),N)
     )
  + cf^3*nf* 320*z5* (
       2*den(N-1)-2*den(N)+den(N+1)
     )
  - cf^2*ca*nf* 160/3*z5* (
       2*den(N-1)-2*den(N)+den(N+1)
     )
  + cf*ca^2*nf* 160/9*z5* (
     - 26* den(N-1)
     + 62* den(N)
     - 49* den(N+1)
     - 24* den(N)^2
     - 12* den(N+1)^2
     )
  + [d4RR/nc]*nf* 640/3*z5* (
       64 * den(N)
     - 68 * den(N+1)
     +  8 * den(N-1)
     - 48 * den(N)^2
     - 24 * den(N+1)^2
    );

* -----------------------------------------------------------------------------
